# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [0.1.1] 2025-05-30

### Changed
- Updated Python API to return copier object from `ezfastq.api.copy` function (#3)


## [0.1] 2025-05-27

Initial release!
